pub enum Backpressure {
TooManyPending,
}Expand description
Reasons for not being able to send due to backpressure
Variants
TooManyPending
There are too many unacked packets outstanding, so we can’t send any more until we receive some acks.